# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.update_call_request import UpdateCallRequest


class TestUpdateCallRequest(unittest.TestCase):
    """UpdateCallRequest unit test stubs"""

    def setUp(self):
        self.model = UpdateCallRequest(
            status=UpdateCallRequestStatus.CANCELED,
        )

    def test_status(self):
        """Test UpdateCallRequest.status"""
        self.model.status = UpdateCallRequestStatus.CANCELED
        assert self.model.status == UpdateCallRequestStatus.CANCELED
        self.model.status = UpdateCallRequestStatus.COMPLETED
        assert self.model.status == UpdateCallRequestStatus.COMPLETED


if __name__ == "__main__":
    unittest.main()
