# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import pydantic_core
from datetime import datetime
import freeclimb
from freeclimb import *
from freeclimb.models.out_dial import OutDial


class TestOutDial(unittest.TestCase):
    """OutDial unit test stubs"""

    def setUp(self):
        self.model = OutDial(
            action_url="TS",
            call_connect_url="TS",
            calling_number="TS",
            destination="TS",
        )

    def test_action_url(self):
        """Test OutDial.action_url"""
        self.model.action_url = "TEST_STRING"
        assert self.model.action_url == "TEST_STRING"

    def test_call_connect_url(self):
        """Test OutDial.call_connect_url"""
        self.model.call_connect_url = "TEST_STRING"
        assert self.model.call_connect_url == "TEST_STRING"

    def test_calling_number(self):
        """Test OutDial.calling_number"""

        self.model.calling_number = "TEST_STRING"
        assert self.model.calling_number == "TEST_STRING"

    def test_destination(self):
        """Test OutDial.destination"""

        self.model.destination = "TEST_STRING"
        assert self.model.destination == "TEST_STRING"

    def test_if_machine(self):
        """Test OutDial.if_machine"""
        self.model.if_machine = IfMachine.REDIRECT
        assert self.model.if_machine == IfMachine.REDIRECT
        self.model.if_machine = IfMachine.HANGUP
        assert self.model.if_machine == IfMachine.HANGUP

    def test_if_machine_url(self):
        """Test OutDial.if_machine_url"""
        self.model.if_machine_url = "TEST_STRING"
        assert self.model.if_machine_url == "TEST_STRING"

    def test_send_digits(self):
        """Test OutDial.send_digits"""

        self.model.send_digits = "TEST_STRING"
        assert self.model.send_digits == "TEST_STRING"

    def test_status_callback_url(self):
        """Test OutDial.status_callback_url"""
        self.model.status_callback_url = "TEST_STRING"
        assert self.model.status_callback_url == "TEST_STRING"

    def test_timeout(self):
        """Test OutDial.timeout"""
        self.model.timeout = 1
        assert self.model.timeout == 1

    def test_privacy_mode(self):
        """Test OutDial.privacy_mode"""
        self.model.privacy_mode = False
        assert self.model.privacy_mode == False


if __name__ == "__main__":
    unittest.main()
